==> devavrata_free_bare-6.x-1.1.tar.gz: devavrata_free_bare/devavrata_core/devavrata_free_bare_4column_engine.php <==
<?php
/***********************************************************
 * Devavrata Core Theme for Drupal - 4-Column Style - No layout Guide - Free Version
 * A WebTheming.com Stylesheet Production
 * Created by Daniel Honrade
 * for paid technical support: mail@danielhonrade.com
 * http://webtheming.com
 * http://danielhonrade.com
 ***********************************************************/
 
/* Generate column regions
 */
function devavrata_free_bare_column_region($column1 = '', $column2 = '', $column3 = '', $column4 = '') {
	if ($column1 || $column2 || $column3 || $column4) { 
		$column_counter = 0; // intialize column counter for final column number class
		if ($column1) { $column_counter++; }; // column 1 named column-1
		if ($column2) { $column_counter++; }; // column 1 & 2 named column-2
		if ($column3) { $column_counter++; }; // column 1,2 & 3 named column-3
		if ($column4) { $column_counter++; }; // column 1,2,3 & 4 named column-4
		
		if ((!$column1 && $column2 && !$column3 && $column4) || ($column1 && !$column2 && $column3 && !$column4)) { $column_counter = 4; $column_middle1 = 'column-widest'; $column_middle2 = 'column-widest'; } // column 1 (25%) + column 3 (75%) or column 2 (75%) + column 4 (25%)
		elseif (!$column1 && $column2 && $column3 && $column4) { $column_counter = 4; $column_middle2 = 'column-wide'; } // column 2 & 4 (25%) + column 3 (50%) 
		elseif ($column1 && !$column2 && $column3 && $column4) { $column_counter = 4; $column_first = 'column-wide'; } // column 1 (25%), 2 (25%) + column 4 (50%)
		elseif ($column1 && $column2 && !$column3 && $column4) { $column_counter = 4; $column_middle3 = 'column-wide'; } // column 1 (50%) + column 3 (25%) & 4 (25%)
		elseif ($column1 && ((!$column2 && $column3) || ($column2 && !$column3)) && $column4 ) { $column_counter = 4; $column_middle2 = 'column-wide'; $column_middle3 = 'column-wide'; } // column 1 (25%)column 2 or 3 (50%) + column 4 (25%)
		elseif (!$column1 && !$column2 && $column3 && $column4) { $column_counter = 3; $column_middle2 = 'column-wider'; } // column 3 (66%) + column 4 (33%)
		elseif ($column1 && $column2 && !$column3 && !$column4) { $column_counter = 3; $column_middle1 = 'column-wider'; } // column 1 (33%) + column 2 (66%)
		else { $column_first = ''; $column_middle1 = ''; $column_middle2 = ''; $column_middle3 = ''; }; // columns back to equal sizes if no above conditions met

		$column_count_final = $column_counter; // final column number class
		$output = '<div id="Preface" class="column-region block-clear block-panel sub-section">';
		
		if ($column1) { $output .= '<div id="Preface-col1" class="column-' . $column_count_final . $column_first   . '-600px column inner-section">' . $column1 .'</div>'; };
		if ($column2) { $output .= '<div id="Preface-col2" class="column-' . $column_count_final . $column_middle1 . '-600px column inner-section">' . $column2 .'</div>'; };
		if ($column3) { $output .= '<div id="Preface-col3" class="column-' . $column_count_final . $column_middle2 . '-600px column inner-section">' . $column3 .'</div>'; };
		if ($column4) { $output .= '<div id="Preface-col4" class="column-' . $column_count_final . $column_middle3 . '-600px column inner-section">' . $column4 .'</div>'; };
		$output  .= '<div class="block-clear"></div></div>';
		return $output;
	}
}

==> devavrata_free_bare-6.x-1.3.tar.gz: devavrata_free_bare/devavrata_core/devavrata_free_bare_4column_engine.php <==
<?php
/***********************************************************
 * Devavrata Core Theme for Drupal - 4-Column Style - No layout Guide - Free Version
 * A WebTheming.com Stylesheet Production
 * Created by Daniel Honrade
 * for paid technical support: mail@danielhonrade.com
 * http://webtheming.com
 * http://danielhonrade.com
 ***********************************************************/
 
/* Generate column regions
 */
function devavrata_free_bare_column_region($column1 = '', $column2 = '', $column3 = '', $column4 = '') {
	if ($column1 || $column2 || $column3 || $column4) { 
		$column_counter = 0; // intialize column counter for final column number class
		if ($column1) { $column_counter++; }; // column 1 named column-1
		if ($column2) { $column_counter++; }; // column 1 & 2 named column-2
		if ($column3) { $column_counter++; }; // column 1,2 & 3 named column-3
		if ($column4) { $column_counter++; }; // column 1,2,3 & 4 named column-4
		
		if ((!$column1 && $column2 && !$column3 && $column4) || ($column1 && !$column2 && $column3 && !$column4)) { $column_counter = 4; $column_middle1 = 'column-widest'; $column_middle2 = 'column-widest'; } // column 1 (25%) + column 3 (75%) or column 2 (75%) + column 4 (25%)
		elseif (!$column1 && $column2 && $column3 && $column4) { $column_counter = 4; $column_middle2 = 'column-wide'; } // column 2 & 4 (25%) + column 3 (50%) 
		elseif ($column1 && !$column2 && $column3 && $column4) { $column_counter = 4; $column_first = 'column-wide'; } // column 1 (25%), 2 (25%) + column 4 (50%)
		elseif ($column1 && $column2 && !$column3 && $column4) { $column_counter = 4; $column_middle3 = 'column-wide'; } // column 1 (50%) + column 3 (25%) & 4 (25%)
		elseif ($column1 && ((!$column2 && $column3) || ($column2 && !$column3)) && $column4 ) { $column_counter = 4; $column_middle2 = 'column-wide'; $column_middle3 = 'column-wide'; } // column 1 (25%)column 2 or 3 (50%) + column 4 (25%)
		elseif (!$column1 && !$column2 && $column3 && $column4) { $column_counter = 3; $column_middle2 = 'column-wider'; } // column 3 (66%) + column 4 (33%)
		elseif ($column1 && $column2 && !$column3 && !$column4) { $column_counter = 3; $column_middle1 = 'column-wider'; } // column 1 (33%) + column 2 (66%)
		else { $column_first = ''; $column_middle1 = ''; $column_middle2 = ''; $column_middle3 = ''; }; // columns back to equal sizes if no above conditions met

		$column_count_final = $column_counter; // final column number class
		$output = '<div id="Preface" class="column-region block-outline block-panel sub-section">';
		
		if ($column1) { $output .= '<div id="Preface-col1" class="column-' . $column_count_final . $column_first   . '-600px column inner-section">' . $column1 .'</div>'; };
		if ($column2) { $output .= '<div id="Preface-col2" class="column-' . $column_count_final . $column_middle1 . '-600px column inner-section">' . $column2 .'</div>'; };
		if ($column3) { $output .= '<div id="Preface-col3" class="column-' . $column_count_final . $column_middle2 . '-600px column inner-section">' . $column3 .'</div>'; };
		if ($column4) { $output .= '<div id="Preface-col4" class="column-' . $column_count_final . $column_middle3 . '-600px column inner-section">' . $column4 .'</div>'; };
		$output  .= '<div class="block-clear"></div></div>';
		return $output;
	}
}
